import { useState } from 'react';
import { isDayBefore, isDayAfter, isSameDay } from '../utils';
export function useDateRange(initialStartDate = new Date(), initialEndDate) {
    const [startDate, setStartDate] = useState(initialStartDate);
    const [endDate, setEndDate] = useState(initialEndDate);
    const [selectionActive, setSelectionActive] = useState(false);
    function handleDayClick(day) {
        if (startDate && selectionActive && !isDayBefore(day, startDate)) {
            setStartDate(startDate);
            setEndDate(day);
            setSelectionActive(false);
        }
        else {
            setStartDate(day);
            setEndDate(undefined);
            setSelectionActive(true);
        }
    }
    function handleDayHover(day) {
        if (selectionActive && startDate && !isDayBefore(day, startDate)) {
            setEndDate(day);
        }
    }
    function processMonth(month) {
        return month.map((week) => week.map((day) => {
            const isStart = startDate && isSameDay(day.date, startDate);
            const isEnd = Boolean(endDate && isSameDay(day.date, endDate));
            return Object.assign({}, day, { selected: isStart || isEnd, inRange: Boolean(startDate &&
                    isDayAfter(day.date, startDate) &&
                    endDate &&
                    isDayBefore(day.date, endDate)), isStart,
                isEnd });
        }));
    }
    return { handleDayClick, handleDayHover, startDate, endDate, processMonth };
}
